==================
zfit Project
==================

Following and introduction to the elements of zfit

.. toctree::
    :titlesonly:
    :maxdepth: 1

    project/installation
    project/contributing
    project/upgrade_guide
    project/changelog
    project/authors

